@@ -12,7 +12,7 @@
 #' This function computes and plots the mean runs scored by the batsman at different
 #' venues of the world
 #' @usage
-#' batsmanRunsVenue(df, name= "A Leg Glance",staticIntv=1)
+#' batsmanRunsVenue(df, name= "A Leg Glance",dateRange,staticIntv=1)
 #'
 #' @param df
 #' Data frame
@@ -20,6 +20,9 @@
 #' @param name
 #' Name of batsman
 #'
+#' @param dateRange
+#' Date interval to consider
+#'
 #' @param staticIntv
 #' Static or interactive -staticIntv =1 (static plot) &  staticIntv =2 (interactive  plot)
 #'
@@ -37,7 +40,7 @@
 #' \dontrun{
 #' #Get the data frame for Kohli
 #' kohli <- getBatsmanDetails(team="India",name="Kohli",dir=pathToFile)
-#' batsmanRunsVenue(kohli,"Kohli")
+#' batsmanRunsVenue(kohli,"Kohli",dateRange)
 #' }
 #'
 #' @seealso
@@ -51,9 +54,10 @@
 #' @export
 #'
 
-batsmanRunsVenue <- function(df,name= "A Leg Glance",staticIntv=1){
+batsmanRunsVenue <- function(df,name= "A Leg Glance",dateRange,staticIntv=1){
     batsman = runs = venue = numMatches = meanRuns = NULL
     ggplotly=NULL
+    df=df %>% filter(date >= dateRange[1] & date <= dateRange[2])
     b <- select(df,batsman,runs,venue)
     c <- summarise(group_by(b,venue),meanRuns=mean(runs),numMatches=n())
     d <- mutate(c,venue=paste(venue,"(",numMatches,")",sep=""))
