@@ -11,14 +11,16 @@
 #' @description
 #' This function gets min,max date and min and max matches from dataframe
 #' @usage
-#' helper(teamNames,odir=".")
+#' helper(teamNames,dir=".",type="IPL")
 #'
 #' @param teamNames
 #' The team names
 #'
-#' @param odir
+#' @param dir
 #' The output directory
 #'
+#' @param type
+#' T20 format
 #'
 #' @return minDate,maxDate, minMatches, maxMatches
 #' @references
@@ -39,32 +41,22 @@
 #' \code{\link{rankT20Bowlers}}\cr
 #' @export
 #'
-helper<- function(teamNames,odir=".") {
+helper<- function(teamNames,dir=".",type="IPL") {
     currDir= getwd()
     battingDetails=batsman=runs=strikeRate=matches=meanRuns=meanSR=battingDF=val=NULL
     year=NULL
+    print("Helper")
+    print(getwd())
+    setwd(dir)
+    print(getwd())
     teams = unlist(teamNames)
 
-    #Change dir
-    setwd(odir)
-
     battingDF<-NULL
-    for(team in teams){
-        battingDetails <- NULL
-        val <- paste(team,"-BattingDetails.RData",sep="")
-        print(val)
-        tryCatch(load(val),
-                 error = function(e) {
-                     print("No data1")
-                     setNext=TRUE
-                 }
-
-
-        )
-        details <- battingDetails
-        battingDF <- rbind(battingDF,details)
-
-    }
+    battingDetails <- paste(type,"-BattingDetails.RData",sep="")
+    print(battingDetails)
+    load(battingDetails)
+    print(dim(battingDF))
+    print(names(battingDF))
     cat("Dir helper =====",getwd(),"\n")
     maxDate= as.Date(max(battingDF$date))
     minDate= as.Date(min(battingDF$date))
@@ -78,6 +70,7 @@ helper<- function(teamNames,odir=".") {
     setwd(currDir)
 
 
+
     cat("Helper **********************************************\n")
     return(list(minDate,maxDate,minMatches, maxMatches))
 
